@@ -142,7 +142,7 @@ ggpairs <- function(
   legends = FALSE,
   verbose = FALSE
 ){
-  require(ggplot2)
+  #require(ggplot2)
   printInfo <- FALSE
 
   verbose = verbose || printInfo
